@@ -22,6 +22,7 @@ DFM_SEARCH_USE_NS
 FileNameWorkerPrivate::FileNameWorkerPrivate(FileNameWorker *qq)
     : q_ptr(qq)
 {
+    qCDebug(logDaemon) << "FileNameWorkerPrivate constructor called";
     m_searchPath = DFMSEARCH::Global::isFileNameIndexDirectoryAvailable()
             ? QDir::rootPath()
             : QDir::homePath();
@@ -30,26 +31,39 @@ FileNameWorkerPrivate::FileNameWorkerPrivate(FileNameWorker *qq)
 
 void FileNameWorkerPrivate::initConfig()
 {
-    qCDebug(logDaemon) << "Initializing search configuration";
+    qCDebug(logDaemon) << "Initializing file search configuration";
+
     // 获取支持的搜索类目
     auto config = ConfigerIns->group(GRANDSEARCH_CLASS_FILE_DEEPIN);
-    if (config->value(GRANDSEARCH_GROUP_FOLDER, false))
+    if (config->value(GRANDSEARCH_GROUP_FOLDER, false)) {
+        qCDebug(logDaemon) << "Folder search enabled";
         m_resultCountHash.insert(FileSearchUtils::Folder, 0);
+    }
 
-    if (config->value(GRANDSEARCH_GROUP_FILE, false))
+    if (config->value(GRANDSEARCH_GROUP_FILE, false)) {
         m_resultCountHash.insert(FileSearchUtils::File, 0);
+        qCDebug(logDaemon) << "File search enabled";
+    }
 
-    if (config->value(GRANDSEARCH_GROUP_FILE_VIDEO, false))
+    if (config->value(GRANDSEARCH_GROUP_FILE_VIDEO, false)) {
         m_resultCountHash.insert(FileSearchUtils::Video, 0);
+        qCDebug(logDaemon) << "Video search enabled";
+    }
 
-    if (config->value(GRANDSEARCH_GROUP_FILE_AUDIO, false))
+    if (config->value(GRANDSEARCH_GROUP_FILE_AUDIO, false)) {
         m_resultCountHash.insert(FileSearchUtils::Audio, 0);
+        qCDebug(logDaemon) << "Audio search enabled";
+    }
 
-    if (config->value(GRANDSEARCH_GROUP_FILE_PICTURE, false))
+    if (config->value(GRANDSEARCH_GROUP_FILE_PICTURE, false)) {
         m_resultCountHash.insert(FileSearchUtils::Picture, 0);
+        qCDebug(logDaemon) << "Picture search enabled";
+    }
 
-    if (config->value(GRANDSEARCH_GROUP_FILE_DOCUMNET, false))
+    if (config->value(GRANDSEARCH_GROUP_FILE_DOCUMNET, false)) {
         m_resultCountHash.insert(FileSearchUtils::Document, 0);
+        qCDebug(logDaemon) << "Document search enabled";
+    }
 
     qCDebug(logDaemon) << "Search groups enabled:" << m_resultCountHash.keys();
 }
@@ -58,29 +72,42 @@ bool FileNameWorkerPrivate::appendSearchResult(const QString &fileName)
 {
     Q_Q(FileNameWorker);
 
-    if (m_tmpSearchResults.contains(fileName))
+    if (m_tmpSearchResults.contains(fileName)) {
+        qCDebug(logDaemon) << "Duplicate file result ignored:" << fileName;
         return false;
+    }
 
     auto group = FileSearchUtils::getGroupByName(fileName);
     Q_ASSERT(group >= FileSearchUtils::GroupBegin && group < FileSearchUtils::GroupCount);
 
     // 根据搜索类目配置判断是否需要进行添加
     if (!m_resultCountHash.contains(group)) {
-        if (group == FileSearchUtils::Folder)
+        if (group == FileSearchUtils::Folder) {
+            qCDebug(logDaemon) << "Folder result ignored - Folder search not enabled:" << fileName;
             return false;
+        }
 
         if (m_resultCountHash.contains(FileSearchUtils::File)) {
             group = FileSearchUtils::File;
+            qCDebug(logDaemon) << "File moved to generic File group:" << fileName;
         } else {
+            qCDebug(logDaemon) << "File result ignored - No matching group enabled:" << fileName;
             return false;
         }
     }
 
-    if (!FileSearchUtils::fileShouldVisible(fileName, group, m_searchInfo))
+    if (!FileSearchUtils::fileShouldVisible(fileName, group, m_searchInfo)) {
+        qCDebug(logDaemon) << "File filtered by visibility rules:" << fileName;
+        return false;
+    }
+
+    if (m_resultCountHash[group] >= MAX_SEARCH_NUM_GROUP)
         return false;
 
-    if (m_resultCountHash[group] >= MAX_SEARCH_NUM_GROUP || FileSearchUtils::filterByBlacklist(fileName))
+    if (FileSearchUtils::filterByBlacklist(fileName)) {
+        qCDebug(logDaemon) << "File filtered by blacklist:" << fileName;
         return false;
+    }
 
     m_tmpSearchResults << fileName;
     const auto &item = FileSearchUtils::packItem(fileName, q->name());
@@ -88,15 +115,22 @@ bool FileNameWorkerPrivate::appendSearchResult(const QString &fileName)
     m_items[group].append(item);
     m_resultCountHash[group]++;
 
+    qCDebug(logDaemon) << "Search result added - File:" << fileName << "Group:" << group
+                       << "Group count:" << m_resultCountHash[group];
+
     // 非文件类目搜索，不需要向文件类目中添加搜索结果
-    if (m_searchInfo.isCombinationSearch && !m_searchInfo.groupList.contains(FileSearchUtils::File))
+    if (m_searchInfo.isCombinationSearch && !m_searchInfo.groupList.contains(FileSearchUtils::File)) {
+        qCDebug(logDaemon) << "Combination search - File group not included, skipping file group addition";
         return true;
+    }
 
     // 文档、音频、视频、图片需添加到文件组中
     if (group != FileSearchUtils::File && m_resultCountHash.contains(FileSearchUtils::File)) {
         if (group != FileSearchUtils::Folder && m_resultCountHash[FileSearchUtils::File] < MAX_SEARCH_NUM_GROUP) {
             m_items[FileSearchUtils::File].append(item);
             m_resultCountHash[FileSearchUtils::File]++;
+            qCDebug(logDaemon) << "File also added to File group - File group count:"
+                               << m_resultCountHash[FileSearchUtils::File];
         }
     }
 
@@ -105,6 +139,8 @@ bool FileNameWorkerPrivate::appendSearchResult(const QString &fileName)
 
 SearchOptions FileNameWorkerPrivate::createSearchOptions() const
 {
+    qCDebug(logDaemon) << "Creating search options - Path:" << m_searchPath;
+
     SearchOptions options;
     options.setSearchPath(m_searchPath);
 
@@ -118,6 +154,7 @@ SearchOptions FileNameWorkerPrivate::createSearchOptions() const
     }
 
     options.setMaxResults(MAX_SEARCH_NUM_TOTAL);
+    qCDebug(logDaemon) << "Search options configured - Max results:" << MAX_SEARCH_NUM_TOTAL;
     return options;
 }
 
@@ -127,28 +164,39 @@ SearchQuery FileNameWorkerPrivate::createSearchQuery() const
     const QStringList &boolKeywords = m_searchInfo.boolKeywords;
     const QStringList &typeKeywords = m_searchInfo.typeKeywords;
 
+    qCDebug(logDaemon) << "Creating search query - Keyword:" << keyword
+                       << "Bool keywords:" << boolKeywords.size()
+                       << "Type keywords:" << typeKeywords.size();
+
     bool useBoolQuery = (boolKeywords.size() >= 2);
     bool useTypeSearch = (typeKeywords.size() >= 2) || m_searchInfo.isCombinationSearch;
     SearchQuery query;
 
     if (useTypeSearch) {
+        qCDebug(logDaemon) << "Using type search mode";
         if (typeKeywords.size() >= 2) {
             query = SearchFactory::createQuery(typeKeywords, SearchQuery::Type::Boolean);
             query.setBooleanOperator(SearchQuery::BooleanOperator::OR);
+            qCDebug(logDaemon) << "Created boolean OR query with type keywords";
         } else if (typeKeywords.size() == 1) {
             query = SearchFactory::createQuery(typeKeywords.first(), SearchQuery::Type::Simple);
+            qCDebug(logDaemon) << "Created simple query with single type keyword";
         } else {
             query = SearchFactory::createQuery(m_searchInfo.keyword, SearchQuery::Type::Simple);
+            qCDebug(logDaemon) << "Created simple query with main keyword";
         }
     } else if (useBoolQuery) {
+        qCDebug(logDaemon) << "Using boolean search mode";
         query = SearchFactory::createQuery(boolKeywords, SearchQuery::Type::Boolean);
     } else {
-        SearchQuery::Type queryType = FileSearchUtils::hasWildcard(keyword) 
-                                    ? SearchQuery::Type::Wildcard 
+        SearchQuery::Type queryType = FileSearchUtils::hasWildcard(keyword)
+                                    ? SearchQuery::Type::Wildcard
                                     : SearchQuery::Type::Simple;
         query = SearchFactory::createQuery(keyword, queryType);
+        qCDebug(logDaemon) << "Created query - Type:" << (queryType == SearchQuery::Type::Wildcard ? "Wildcard" : "Simple");
     }
 
+    qCDebug(logDaemon) << "Search query created successfully";
     return query;
 }
 
@@ -157,24 +205,33 @@ void FileNameWorkerPrivate::configureFileNameOptions(FileNameOptionsAPI &fileNam
     const QString &keyword = m_searchInfo.keyword;
     const QStringList &typeKeywords = m_searchInfo.typeKeywords;
 
+    qCDebug(logDaemon) << "Configuring file name options";
+
     bool useTypeSearch = (typeKeywords.size() >= 2) || m_searchInfo.isCombinationSearch;
 
     if (useTypeSearch) {
+        qCDebug(logDaemon) << "Type search configuration - Enabling pinyin and setting file types";
         fileNameOptions.setPinyinEnabled(true);
         fileNameOptions.setFileTypes(FileSearchUtils::buildDFMSearchFileTypes(m_searchInfo.groupList));
         fileNameOptions.setFileExtensions(m_searchInfo.suffixList);
+        qCDebug(logDaemon) << "File extensions configured:" << m_searchInfo.suffixList;
     } else if (query.type() == SearchQuery::Type::Boolean) {
+        qCDebug(logDaemon) << "Boolean query configuration - Enabling pinyin";
         fileNameOptions.setPinyinEnabled(true);
     } else if (query.type() == SearchQuery::Type::Wildcard) {
+        qCDebug(logDaemon) << "Wildcard query configuration - Disabling pinyin";
         // 通配符搜索通常不需要拼音支持，因为用户输入的是精确的模式
         fileNameOptions.setPinyinEnabled(false);
     } else if (FileSearchUtils::isPinyin(keyword)) {
+        qCDebug(logDaemon) << "Pinyin keyword detected - Enabling pinyin support";
         fileNameOptions.setPinyinEnabled(true);
     }
 }
 
 bool FileNameWorkerPrivate::processSearchResults(const SearchResultExpected &result)
 {
+    qCDebug(logDaemon) << "Processing search results";
+
     if (!result.hasValue()) {
         qCWarning(logDaemon) << "Search failed for keyword:" << m_searchInfo.keyword
                              << "Error:" << result.error().message();
@@ -192,8 +249,10 @@ bool FileNameWorkerPrivate::processSearchResults(const SearchResultExpected &res
         tryNotify();
 
         // perf: 降频
-        if (index % 100 == 0 && isResultLimit())
+        if (index % 100 == 0 && isResultLimit()) {
+            qCDebug(logDaemon) << "Result limit reached - Breaking search loop at index:" << index;
             break;
+        }
 
         ++index;
     }
@@ -223,8 +282,10 @@ bool FileNameWorkerPrivate::searchByDFMSearch()
 
     // 设置搜索选项
     engine->setSearchOptions(options);
+    qCDebug(logDaemon) << "Search options configured on engine";
 
     // 执行搜索并处理结果
+    qCDebug(logDaemon) << "Executing synchronous search";
     const SearchResultExpected &result = engine->searchSync(query);
     return processSearchResults(result);
 }
@@ -264,10 +325,12 @@ FileNameWorker::FileNameWorker(const QString &name, QObject *parent)
     : ProxyWorker(name, parent),
       d_ptr(new FileNameWorkerPrivate(this))
 {
+    qCDebug(logDaemon) << "FileNameWorker constructor - Name:" << name;
 }
 
 FileNameWorker::~FileNameWorker()
 {
+    qCDebug(logDaemon) << "FileNameWorker destructor called";
     delete d_ptr;
     d_ptr = nullptr;
 }
@@ -279,6 +342,7 @@ void FileNameWorker::setContext(const QString &context)
     if (context.isEmpty())
         qCWarning(logDaemon) << "Search key is empty";
     d->m_searchInfo = FileSearchUtils::parseContent(context);
+    qCDebug(logDaemon) << "Parsed search keyword:" << d->m_searchInfo.keyword;
 }
 
 bool FileNameWorker::isAsync() const
@@ -291,6 +355,8 @@ bool FileNameWorker::working(void *context)
     Q_D(FileNameWorker);
     Q_UNUSED(context)
 
+    qCDebug(logDaemon) << "FileNameWorker starting work";
+
     if (!d->m_status.testAndSetRelease(Ready, Runing)) {
         qCWarning(logDaemon) << "Failed to start worker - Invalid state transition";
         return false;
@@ -350,6 +416,8 @@ MatchedItemMap FileNameWorker::takeAll()
 {
     Q_D(FileNameWorker);
 
+    qCDebug(logDaemon) << "Taking all search results";
+
     // 添加分组
     MatchedItemMap ret;
 
