@@ -24,11 +24,15 @@ HandleVisibility::HandleVisibility(MainWindow *mainWindow, QObject *parent)
       m_mainWindow(mainWindow)
 // , m_sessionManagerInter(new com::deepin::SessionManager(SessionManagerService, SessionManagerPath, QDBusConnection::sessionBus(), this))
 {
+    qCDebug(logGrandSearch) << "Creating HandleVisibility";
     init();
+    qCDebug(logGrandSearch) << "HandleVisibility created successfully";
 }
 
 void HandleVisibility::init()
 {
+    qCDebug(logGrandSearch) << "Initializing visibility handler";
+
     m_regionMonitor = new DRegionMonitor(this);
     m_regionMonitor->setCoordinateType(DRegionMonitor::ScaleRatio);
     // 鼠标点击主界面之外的区域，退出进程
@@ -61,6 +65,8 @@ void HandleVisibility::onLockedChanged(const bool locked)
 {
     Q_ASSERT(m_mainWindow);
 
+    qCDebug(logGrandSearch) << "Screen lock state changed - Locked:" << locked
+                            << "Setting window visible:" << !locked;
     m_mainWindow->setVisible(!locked);
 }
 
@@ -68,6 +74,7 @@ void HandleVisibility::onCloseWindow()
 {
     Q_ASSERT(m_mainWindow);
 
+    qCDebug(logGrandSearch) << "Closing main window";
     m_mainWindow->close();
 }
 
@@ -77,6 +84,8 @@ void HandleVisibility::registerRegion(const bool isRegister)
 
     if (isRegister == m_regionMonitor->registered())
         return;
+
+    qCDebug(logGrandSearch) << "Region registration:" << isRegister;
     // FIXME: how to fix blocked 25s issue on treeland
     /*
     if (isRegister)
