@@ -5,6 +5,9 @@
 #include "checkboxitem.h"
 
 #include <QVBoxLayout>
+#include <QLoggingCategory>
+
+Q_DECLARE_LOGGING_CATEGORY(logGrandSearch)
 
 #define RADIUS 8
 
@@ -14,6 +17,7 @@ DWIDGET_USE_NAMESPACE
 CheckBoxItem::CheckBoxItem(const QString &text, QWidget *parent)
     : RoundedBackground(parent)
 {
+    qCDebug(logGrandSearch) << "Creating CheckBoxItem - Text:" << text;
     m_checkBox = new DCheckBox(text, parent);
     auto mainLayout = new QVBoxLayout;
     mainLayout->addWidget(m_checkBox);
@@ -22,14 +26,18 @@ CheckBoxItem::CheckBoxItem(const QString &text, QWidget *parent)
     setLayout(mainLayout);
 
     connect(m_checkBox, &DCheckBox::toggled, this, &CheckBoxItem::toggled);
+    qCDebug(logGrandSearch) << "CheckBoxItem created successfully - Text:" << text;
 }
 
 CheckBoxItem::~CheckBoxItem()
 {
+    qCDebug(logGrandSearch) << "Destroying CheckBoxItem";
 }
 
 void CheckBoxItem::setChecked(bool checked)
 {
+    qCDebug(logGrandSearch) << "Setting checkbox item state - Text:" << text()
+                            << "Checked:" << checked;
     m_checkBox->setChecked(checked);
 }
 
