@@ -55,6 +55,7 @@ static QDBusMessage createVectorMsg(const QString &method)
 IntelligentRetrievalWidget::IntelligentRetrievalWidget(QWidget *parent)
     : DWidget(parent)
 {
+    qCDebug(logGrandSearch) << "Creating IntelligentRetrievalWidget";
 
     m_mainLayout = new QVBoxLayout();
     setLayout(m_mainLayout);
@@ -197,6 +198,8 @@ IntelligentRetrievalWidget::IntelligentRetrievalWidget(QWidget *parent)
 #endif
     connect(m_featIndex, &SwitchWidget::checkedChanged, this, &IntelligentRetrievalWidget::checkChanged);
     connect(m_fullTextIndex, &SwitchWidget::checkedChanged, this, &IntelligentRetrievalWidget::checkChanged);
+
+    qCDebug(logGrandSearch) << "IntelligentRetrievalWidget created - AI Search enabled:" << turnOn;
 }
 
 void IntelligentRetrievalWidget::updateState()
@@ -373,7 +376,9 @@ QVariantHash IntelligentRetrievalWidget::getIndexStatus()
 
     ret.waitForFinished();
     if (ret.error().type() != QDBusError::NoError) {
-        qWarning() << "error: " << msg.service() << QDBusError::errorString(ret.error().type()) << ret;
+        qCWarning(logGrandSearch) << "Failed to get semantic status - Service:" << msg.service()
+                                  << "Error:" << QDBusError::errorString(ret.error().type())
+                                  << "Response:" << ret;
         return QVariantHash();
     }
 
@@ -411,6 +416,8 @@ void IntelligentRetrievalWidget::updateIndexStatusContent(const QVariantHash &st
 
 void IntelligentRetrievalWidget::setFulltextQuery(bool on)
 {
+    qCDebug(logGrandSearch) << "Full text search configuration changed - Enabled:" << on;
+
     SearchConfig::instance()->setConfig(GRANDSEARCH_SEMANTIC_GROUP, GRANDSEARCH_CLASS_GENERALFILE_SEMANTIC_FULLTEXT, on);
     // 调用文管接口，没开就打开
     if (on) {
@@ -436,7 +443,8 @@ void IntelligentRetrievalWidget::setAutoIndex(bool on)
     QDBusPendingReply<void> ret = QDBusConnection::sessionBus().asyncCall(msg, 500);
     ret.waitForFinished();
     if (ret.error().type() != QDBusError::NoError) {
-        qWarning() << "error: " << msg.service() << QDBusError::errorString(ret.error().type());
+        qCWarning(logGrandSearch) << "Failed to set auto index - Service:" << msg.service()
+                                  << "Error:" << QDBusError::errorString(ret.error().type());
     }
     return;
 }
