@@ -4,6 +4,7 @@
 
 #include "environments.h"
 #include "global/grandsearch_global.h"
+#include "global/framelogmanager.h"
 
 #include "gui/mainwindow.h"
 #include "gui/searchconfig/configwidget.h"
@@ -25,6 +26,8 @@
 
 #include <unistd.h>
 
+Q_LOGGING_CATEGORY(logGrandSearch, "org.deepin.dde.GrandSearch.GrandSearch")
+
 GRANDSEARCH_USE_NAMESPACE
 DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
@@ -44,10 +47,7 @@ int main(int argc, char *argv[])
 #endif
 
     // 设置终端和文件记录日志
-    const QString logFormat = "%{time}{yyyyMMdd.HH:mm:ss.zzz}[%{type:1}][%{function:-35} %{line:-4} %{threadid} ] %{message}\n";
-    DLogManager::setLogFormat(logFormat);
-    DLogManager::registerConsoleAppender();
-    DLogManager::registerFileAppender();
+    dgsLogManager->applySuggestedLogSettings();
 
     QCommandLineParser parser;
 
@@ -55,7 +55,7 @@ int main(int argc, char *argv[])
     QString position;
 
     if (argc > 1) {
-        QCommandLineOption option_setting({"s", "setting"}, "Start grand search config.");
+        QCommandLineOption option_setting({ "s", "setting" }, "Start grand search config.");
         QCommandLineOption option_position("position", "Start grand search config, and scroll to one position.", "value");
 
         parser.addOption(option_setting);
@@ -64,24 +64,28 @@ int main(int argc, char *argv[])
 
         parser.process(app);
         isSetting = parser.isSet(option_setting);
-        position  = parser.value(option_position);
+        position = parser.value(option_position);
     }
     // 根据要求，通过启动参数决定显示界面
-    if (isSetting) { // 设置界面
+    if (isSetting) {   // 设置界面
         // 设置单例运行程序
         if (!app.setSingleInstance("dde-grand-search-config")) {
-            qWarning() << "set single instance failed!I (pid:" << getpid() << ") will exit.";
+            qCWarning(logGrandSearch) << "Failed to set single instance mode - PID:" << getpid()
+                                      << "Application will exit";
             return -1;
         }
 
         // 加载翻译
         app.loadTranslator();
 
-        qDebug() << "starting config:" << app.applicationName() << app.applicationVersion() << getpid();
+        qCInfo(logGrandSearch) << "Starting configuration interface - Application:" << app.applicationName()
+                               << "Version:" << app.applicationVersion()
+                               << "PID:" << getpid();
 
         ConfigWidget w;
         w.show();
         if (position == "aiconfig") {
+            qCDebug(logGrandSearch) << "Scrolling to AI configuration section";
             w.scrollToAiConfig();
         }
         Dtk::Widget::moveToCenter(&w);
@@ -90,17 +94,20 @@ int main(int argc, char *argv[])
         QObject::connect(&app, &DApplication::newInstanceStarted, &w, &ConfigWidget::activateWindow);
 
         return app.exec();
-    } else {    // 搜索界面
+    } else {   // 搜索界面
         // 设置单例运行程序
         if (!app.setSingleInstance("dde-grand-search")) {
-            qWarning() << "set single instance failed!I (pid:" << getpid() << ") will exit.";
+            qCWarning(logGrandSearch) << "Failed to set single instance mode - PID:" << getpid()
+                                      << "Application will exit";
             return -1;
         }
 
         // 加载翻译
         app.loadTranslator();
 
-        qDebug() << "starting search:" << app.applicationName() << app.applicationVersion() << getpid();
+        qCInfo(logGrandSearch) << "Starting search interface - Application:" << app.applicationName()
+                               << "Version:" << app.applicationVersion()
+                               << "PID:" << getpid();
 
         // 解析点选数据
         AccessRecord::instance()->startParseRecord();
@@ -109,7 +116,7 @@ int main(int argc, char *argv[])
         MainWindow mainWindow;
         mainWindow.show();
 
-        QTimer::singleShot(0, &mainWindow, [&mainWindow](){
+        QTimer::singleShot(0, &mainWindow, [&mainWindow]() {
             // 界面初始化完成后，再处理与业务有关的连接
             mainWindow.connectToController();
         });
@@ -117,22 +124,25 @@ int main(int argc, char *argv[])
         // 注册dbus服务
         QDBusConnection conn = QDBusConnection::sessionBus();
         if (!conn.isConnected()) {
-            qWarning() << "QDBusConnection is not connect.";
+            qCCritical(logGrandSearch) << "Failed to connect to D-Bus session bus";
             return -1;
         }
 
         GrandSearchService service(&mainWindow);
         Q_UNUSED(new GrandSearchServiceAdaptor(&service))
         if (!conn.registerService(GrandSearchViewServiceName)) {
-            qWarning() << "registerService Failed:" << conn.lastError();
+            qCCritical(logGrandSearch) << "Failed to register D-Bus service:" << conn.lastError().message();
             return -1;
         }
 
         if (!conn.registerObject(GrandSearchViewServicePath, &service)) {
-            qWarning() << "registerObject Failed:" << conn.lastError();
+            qCCritical(logGrandSearch) << "Failed to register D-Bus object:" << conn.lastError().message();
             return -1;
         }
 
+        qCInfo(logGrandSearch) << "D-Bus service registered successfully - Service:" << GrandSearchViewServiceName
+                               << "Path:" << GrandSearchViewServicePath;
+
         return app.exec();
     }
 }
