@@ -27,11 +27,12 @@ AudioPreviewPlugin::AudioPreviewPlugin(QObject *parent)
     : QObject (parent)
     , PreviewPlugin()
 {
-
+    qCDebug(logAudioPreview) << "AudioPreviewPlugin created";
 }
 
 AudioPreviewPlugin::~AudioPreviewPlugin()
 {
+    qCDebug(logAudioPreview) << "AudioPreviewPlugin destroyed";
     if (m_audioView)
         m_audioView->deleteLater();
 }
@@ -39,21 +40,31 @@ AudioPreviewPlugin::~AudioPreviewPlugin()
 void AudioPreviewPlugin::init(QObject *proxyInter)
 {
     Q_UNUSED(proxyInter)
-    if (!m_audioView)
+    qCDebug(logAudioPreview) << "Initializing AudioPreviewPlugin";
+    if (!m_audioView) {
         m_audioView = new AudioView();
+        qCDebug(logAudioPreview) << "AudioView created";
+    }
 }
 
 bool AudioPreviewPlugin::previewItem(const ItemInfo &item)
 {
     const QString path = item.value(PREVIEW_ITEMINFO_ITEM);
-    if (path.isEmpty())
+    if (path.isEmpty()) {
+        qCWarning(logAudioPreview) << "Audio file path is empty - Cannot preview";
         return false;
+    }
+
+    qCDebug(logAudioPreview) << "Previewing audio file - Path:" << path;
 
     m_audioView->setItemInfo(item);
 
     AudioFileInfo afi;
     AudioFileInfo::AudioMetaData amd = afi.openAudioFile(path);
 
+    qCDebug(logAudioPreview) << "Audio metadata - Artist:" << amd.artist
+                             << "Album:" << amd.album << "Duration:" << amd.duration;
+
     // 歌手 尾部截断
     DetailTagInfo tagInfos;
     tagInfos.insert(DetailInfoProperty::Text, QVariant(tr("Artist:")));
@@ -145,6 +156,7 @@ bool AudioPreviewPlugin::previewItem(const ItemInfo &item)
     m_detailInfos.push_back(detailInfo);
 
     m_item = item;
+    qCDebug(logAudioPreview) << "Audio preview completed successfully - Path:" << path;
     return true;
 }
 
@@ -155,6 +167,7 @@ ItemInfo AudioPreviewPlugin::item() const
 
 bool AudioPreviewPlugin::stopPreview()
 {
+    qCDebug(logAudioPreview) << "Stopping audio preview";
     return true;
 }
 
